==> adblock-plus_0.7.5.4.orig.tar.gz: adblock-plus-0.7.5.4/defaults/preferences/adblockplus.js <==
// For description of these values see http://adblockplus.org/en/preferences

pref("extensions.adblockplus.enabled", true);
pref("extensions.adblockplus.frameobjects", true);
pref("extensions.adblockplus.fastcollapse", false);
pref("extensions.adblockplus.warnregexp", true);
pref("extensions.adblockplus.showintoolbar", true);
pref("extensions.adblockplus.showinstatusbar", false);
pref("extensions.adblockplus.checkedtoolbar", false);
pref("extensions.adblockplus.checkedadblockinstalled", false);
pref("extensions.adblockplus.showsubscriptions", true);
pref("extensions.adblockplus.detachsidebar", false);
pref("extensions.adblockplus.synchronizationinterval", 24);
pref("extensions.adblockplus.defaulttoolbaraction", 1);
pref("extensions.adblockplus.defaultstatusbaraction", 2);
pref("extensions.adblockplus.sidebar_key", "Accel Shift V");
pref("extensions.adblockplus.settings_key", "Accel Shift E");
pref("extensions.adblockplus.enable_key", "");
pref("extensions.adblockplus.flash_scrolltoitem", true);
pref("extensions.adblockplus.previewimages", true);
pref("extensions.adblockplus.patternsfile", "adblockplus/patterns.ini");
pref("extensions.adblockplus.patternsbackups", 5);
pref("extensions.adblockplus.patternsbackupinterval", 24);
pref("extensions.adblockplus.whitelistschemes", "about chrome file irc mailto news resource snews x-jsd addbook cid imap mailbox nntp pop data javascript moz-icon");
pref("extensions.adblockplus.hideimagemanager", true);
pref("extensions.adblockplus.protectchrome.abp", "adblockplus");
pref("extensions.adblockplus.subscriptions_fallbackurl", "http://adblockplus.org/getSubscription?url=%s");
pref("extensions.adblockplus.subscriptions_fallbackerrors", 50);
pref("extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description", "chrome://adblockplus/locale/global.properties");

==> adblock-plus_1.1.1.orig.tar.gz: adblock-plus-1.1.1/defaults/preferences/adblockplus.js <==
// For description of these values see http://adblockplus.org/en/preferences

pref("extensions.adblockplus.currentVersion", "0.0");
pref("extensions.adblockplus.enabled", true);
pref("extensions.adblockplus.frameobjects", true);
pref("extensions.adblockplus.fastcollapse", false);
pref("extensions.adblockplus.showintoolbar", true);
pref("extensions.adblockplus.showinstatusbar", false);
pref("extensions.adblockplus.detachsidebar", false);
pref("extensions.adblockplus.synchronizationinterval", 24);
pref("extensions.adblockplus.defaulttoolbaraction", 1);
pref("extensions.adblockplus.defaultstatusbaraction", 2);
pref("extensions.adblockplus.sidebar_key", "Accel Shift V");
pref("extensions.adblockplus.settings_key", "Accel Shift E");
pref("extensions.adblockplus.enable_key", "");
pref("extensions.adblockplus.flash_scrolltoitem", true);
pref("extensions.adblockplus.previewimages", true);
pref("extensions.adblockplus.patternsfile", "adblockplus/patterns.ini");
pref("extensions.adblockplus.patternsbackups", 5);
pref("extensions.adblockplus.patternsbackupinterval", 24);
pref("extensions.adblockplus.whitelistschemes", "about chrome file irc news resource snews x-jsd addbook cid imap mailbox nntp pop data javascript moz-icon");
pref("extensions.adblockplus.hideimagemanager", true);
pref("extensions.adblockplus.subscriptions_fallbackurl", "http://adblockplus.org/getSubscription?url=%s");
pref("extensions.adblockplus.subscriptions_fallbackerrors", 5);
pref("extensions.adblockplus.savestats", true);
pref("extensions.adblockplus.composer_default", 2);
pref("extensions.adblockplus.clearStatsOnHistoryPurge", true);
pref("extensions.{d10d0bf8-f5b5-c8b4-a8b2-2b9879e08c5d}.description", "chrome://adblockplus/locale/global.properties");
